Rasters for Django
==================

.. image:: https://travis-ci.org/geodesign/django-raster.svg?branch=master
    :target: https://travis-ci.org/geodesign/django-raster

.. image:: https://coveralls.io/repos/github/geodesign/django-raster/badge.svg?branch=master
    :target: https://coveralls.io/github/geodesign/django-raster?branch=master

Django-raster provides raster data integration for Django projects
with a PostGIS database backend.

`See the docs for more information`__

__ http://django-raster.readthedocs.org/en/latest/
